% -------------------------- CSER detection demo -----------------------
%
% Files description
% cser.exe      - compiled cser detector (type "cser -help" to see info)
% lp_*.*        - detector data files (used by cser.exe)
% output.data   - list of detected CSER (generated by cser.exe)
% demo.m        - this file.
% readCSER.m    - cser reader from "output.data" file to region structure.
% showRegion.m  - plot of region structure.

% Initialization

listPath = {'big.bmp' 'small.bmp' 'angle.bmp'}; 
%listPath = {'img4.bmp' 'img1.bmp' 'img3.bmp'}; 
%listPath = {'text_5.bmp' 'text_6.bmp' 'text_7.bmp'}; 
w = 100; h =20; nl = sprintf('\n');

for i = 1:length(listPath),
    
    imPath = listPath{i};
    
    % CSER detection
    command=['cser -i ',imPath,' -ms 20 -mp 0.5 -e 1000 -n lp_ -th 0.0 -dl 3'];
    t0 = clock; [a,b] = dos(command); tCSER = etime(clock,t0);
    reg = readCSER('output.data');
    
    % Linear configurations detection
    addpath([pwd,'\linear_conf']); 
    im = imread(imPath); clear img; img(:,:,1) = im; img(:,:,2) = im; img(:,:,3) = im;
    t0 = clock; LP  = associateRegions(reg, img); tLC = etime(clock,t0);
    
    % LP normalization
    t0 = clock;
    for j = 1:length(LP),
        [LP(j).img] = imgMap(LP(j).rect, [1 1; w 1; w h; 1 h], double(im));
    end;
    tNORM = etime(clock,t0);

    
    % Visualization    
    [r c] = size(im);
    subplot(3,3,3*(i-1) + 1); imshow(im); title(['file: ', imPath]);
    subplot(3,3,3*(i-1) + 2); showRegions(reg); axis([0 c -r 0]); 
    if length(LP)>0,
        for j=1:length(LP),
            subplot(3,3,3*(i-1) + 2); hold on;  plot([LP(j).rect(:,1); LP(j).rect(1,1)] , -[LP(j).rect(:,2); LP(j).rect(1,2)] ,'ro-' ); title(['LC length: ',num2str(length(LP(j).numReg)),' reg.']);
            subplot(3,3,3*(i-1) + 3); imshow(LP(j).img); 
        end;
    end;
    subplot(3,3,3*(i-1) + 3);
    title(['timeCSER: ' ,num2str(tCSER), 's',nl, 'timeLC: ' ,num2str(tLC), 's', nl, 'timeNorm: ' ,num2str(tNORM), 's', nl, b(strfind(b,'ER'):end)]);    
end;
%figure;
%img_out=img; for i=1:length(LP), img_out = drawRect(img_out, LP(i).rect); end; imshow(img_out);
%print('-depsc', 'img_out.eps');
